Index: trunk/MagicSoft/Mars/mfbase/MFDataChain.cc
===================================================================
--- trunk/MagicSoft/Mars/mfbase/MFDataChain.cc	(revision 7810)
+++ trunk/MagicSoft/Mars/mfbase/MFDataChain.cc	(revision 8076)
@@ -28,5 +28,5 @@
 //
 // With this filter you can filter in all variables from Mars parameter
 // containers using rules (for more details see MDataChain).
 //
 // In the constructor you can give the filter variable, like
@@ -52,4 +52,5 @@
 
 #include "MDataValue.h"
+#include "MDataPhrase.h"
 
 #include "MLog.h"
@@ -86,5 +87,5 @@
 MFDataChain::MFDataChain(const char *rule, const char type, const char *cond,
                          const char *name, const char *title)
-    : fData(rule), fCond(new MDataChain(cond))
+    : fData(rule), fCond(new MDataPhrase(cond))
 {
     fName  = name  ? name  : "MFDataChain";
@@ -28,5 +28,5 @@
 //
 // With this filter you can filter in all variables from Mars parameter
-// containers using rules (for more details see MDataChain).
+// containers using rules (for more details see MDataPhrase).
 //
 // In the constructor you can give the filter variable, like
